@@ -1,9 +1,8 @@
 
 make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL, 
                           titlestr=NULL, itemlabvec=NULL, optlabList=NULL,
-                          nbin=nbinDefault(N), NumBasis=7, SfdPar=NULL,
-                          jitterwrd=TRUE, PcntMarkers=c( 5, 25, 50, 75, 95),
-                          verbose=FALSE) {
+                          nbin=nbinDefault(N), NumBasis=7, jitterwrd=TRUE, 
+                          PcntMarkers=c( 5, 25, 50, 75, 95), verbose=FALSE) {
   
   #' This function sets up the information required to analyze a set of data.
   #' The information is stored in the struct object dataStr.
@@ -52,7 +51,7 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
   #. nbin        ...  The number of bins containing proportions of choices.
   #. NumBasis    ...  The number of spline basis functions to use for 
   #.                  surprisal values.  Defaults to 7.
-  #. SfdPar      ...  A functional parameter object to be used for representing
+  #. Sfd         ...  A functional data object to be used for representing
   #.                  surprisal curves.  May be NULL in which case the spline  
   #                   basis has NumBasis basis functions and is of order 5.
   #. jitterwrd   ...  A logical object indicating whether a small jittering
@@ -62,12 +61,13 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
   #                   in plots.  Defaults to c(5, 25, 50, 75, 95).
   #. verbose     ...  Extra displays are provided.  Defaults to FALSE.
   
-  #  Last modified 28 November 2023 by Jim Ramsay
+  #  Last modified 8 January 2024 by Jim Ramsay
   
   #. Dimensions of index matrix
   
-  N <- nrow(chcemat)
-  n <- ncol(chcemat)
+  N     <- nrow(chcemat)
+  n     <- ncol(chcemat)
+  nitem <- length(noption)
   
   #. --------------------------------------------------------------------------
   #.                          Check Arguments
@@ -86,7 +86,8 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
   #.    Garbage options indicating missing of illegal values are not added.
 
   if (is.null(noption))          stop("Vector noption is NULL.")
-  if (length(noption) != n)      stop("Argument noption is not of length n.")
+  if ((length(noption) != n) && (length(noption) != n + 1))      
+                                 stop("Argument noption is not of length n.")
   if (any(is.na(noption)))       stop("A value in noption is NA.")
   if (min(noption) < 2)          stop("Values less than 2 in noption.")
   # if (any(!is.integer(noption))) stop("Non-integer values in noption.")
@@ -104,10 +105,10 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
     key <- scoreList
     if (min(key) < 1) stop(paste("Zero data values encountered in key.",
                                  "Are they score values?"))
-    if (max(abs(as.integer(key)-key)) > 0) 
+    if (max(abs(as.integer(key)-key)) > 0)
       stop("Non-integer values found in key.")
-    if (length(key) != n && length(key) > 0) 
-      stop("length of key is neither n nor 0") 
+    if (length(key) != n && length(key) > 0)
+      stop("length of key is neither n nor 0")
     for (i in 1:n) {
       keyerror <- FALSE
       if (key[i] > noption[i]) {
@@ -117,7 +118,7 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
       }
     }
     if (keyerror) stop("")
-    #  Set up key as scoreList,  a numbered list.
+    # Set up key as scoreList,  a numbered list.
     #. each list element is a vector with values 0 or 1
     scoreList <- vector("list",n)
     for (i in 1:n) {
@@ -126,22 +127,22 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
       scoreList[[i]] <- scoreveci
     }
   }
-  
-  #  check itemlabvec
-  
+
+  # check itemlabvec
+
   if (!is.null(itemlabvec)) {
     if (length(itemlabvec) != n ) stop("Number of item labels is not n.")
     if (!is.character(itemlabvec)) itemlabvec <- as.character(itemlabvec)
   }
-  
-  #  check optlabList
-  
+  #
+  # check optlabList
+  #
   if (!is.null(optlabList)) {
-    if (length(optlabList) != n ) 
+    if (length(optlabList) != n )
       stop("Number of option label sets is not n.")
     for (i in 1:n) {
-      for (m in 1:noption[i]) 
-        if (!is.character(optlabList[[i]])) 
+      for (m in 1:noption[i])
+        if (!is.character(optlabList[[i]]))
           optlabList[[i]] <- as.character(optlabList[[i]])
     }
   }
@@ -246,26 +247,18 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
   
   #  number of basis functions.  If NULL, this is assigned according to size of N
   
-  if (is.null(SfdPar)) {
-    #  Default fdPar objects for representing functions
-    if (round(NumBasis) == NumBasis) {
-      #  NumBasis is an integer
-      if (NumBasis < 2) 
-        stop("There must be at least two spline basis functions.")
-      if (NumBasis > 7) 
-        warning("More than 7 basis functions may cause instability 
+  if (round(NumBasis) == NumBasis) {
+    #  NumBasis is an integer
+    if (NumBasis < 2) 
+      stop("There must be at least two spline basis functions.")
+    if (NumBasis > 7) 
+      warning("More than 7 basis functions may cause instability 
                 in optimization.")
-      Snbasis <- NumBasis
-      Snorder <- min(Snbasis, 5)
-      Sbasis  <- fda::create.bspline.basis(c(0,100), Snbasis, Snorder) 
-      SfdPar  <- fda::fdPar(Sbasis)
-    } else {
-      stop("Number of basis functions is not an integer.")
-    }
+    Snbasis <- NumBasis
+    Snorder <- min(Snbasis, 5)
+    Sbasis  <- fda::create.bspline.basis(c(0,100), Snbasis, Snorder) 
   } else {
-    if (inherits(SfdPar, "basisfd") || inherits(SfdPar, "fd"))
-      SfdPar <- fdPar(SfdPar)
-    if (!inherits(SfdPar, "fdPar")) stop("SfdPar is not an fdPar object.")
+    stop("Number of basis functions is not an integer.")
   }
   
   #. --------------------------------------------------------------------------
@@ -273,32 +266,34 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
   #.    using functional data smoothing.
   #. --------------------------------------------------------------------------
   
-  SfdList <- Sbinsmth.init(percntrnk, nbin, SfdPar, grbgvec, noption, chcemat) 
+  SfdList <- Sbinsmth.init(percntrnk, nbin, Sbasis, key, grbgvec, 
+                           noption, chcemat) 
   
   ##  Construct dataList object to define data Listucture
   
   dataList <- list(chcemat     = chcemat, 
-                   scoreList   = scoreList,
-                   noption     = noption, 
+                   key         = key,
                    titlestr    = titlestr,
+                   N           = N,
+                   n           = n,
+                   noption     = noption, 
+                   Sdim        = Sdim, 
+                   grbgvec     = grbgvec,
+                   scoreList   = scoreList,
+                   nbin        = nbin, 
+                   NumBasis    = NumBasis,
+                   Sbasis      = Sbasis,
                    itemlabvec  = itemlabvec,
                    optlabList  = optlabList,
-                   SfdList     = SfdList,
-                   key         = key,
-                   grbgvec     = grbgvec,
-                   SfdPar      = SfdPar, 
-                   nbin        = nbin, 
-                   sumscr_rng  = sumscr_rng, 
-                   scrfine     = scrfine,
                    scrvec      = scrvec,
-                   scrjit      = scrjit,
                    itmvec      = itmvec, 
-                   percntrnk   = percntrnk, 
+                   scrjit      = scrjit,
+                   sumscr_rng  = sumscr_rng, 
+                   SfdList     = SfdList,
+                   scrfine     = scrfine,
                    indexQnt    = indexQnt,
-                   Sdim        = Sdim, 
-                   PcntMarkers = PcntMarkers,
-                   N           = N,
-                   n           = n)
+                   percntrnk   = percntrnk, 
+                   PcntMarkers = PcntMarkers)
   
   return(dataList)
   
@@ -306,20 +301,25 @@ make_dataList <- function(chcemat, scoreList, noption, sumscr_rng=NULL,
 
 #  ---------------------------------------------------------------
 
-Sbinsmth.init <- function(percntrnk, nbin, SfdPar, grbgvec, noption, chcemat) {
+Sbinsmth.init <- function(percntrnk, nbin, Sbasis, key, grbgvec, 
+                          noption, chcemat) {
   
-  # Last modified 26 November 2023 by Jim Ramsay
+  # Last modified 8 January 2024 by Jim Ramsay
   
   #  This version of Sbinsmth() uses direct least squares smoothing of the
   #  surprisal values at bin centers to generate dependent variables for
   #  a model for the vectorized K by M-1 parameter matrix Bmat.
   
-  nitem     <- ncol(chcemat)
-  chartList <- vector("list", nitem)
+  #. --------------------------------------------------------------------------
+  #. Compute SListi for the n test items
+  #. --------------------------------------------------------------------------
+  
+  n         <- ncol(chcemat)
+  nitem     <- length(noption)
   indfine   <- seq(0,100, len=101)
   indexQnt  <- seq(0,100, len=2*nbin+1)  
   bdry      <- indexQnt[seq(1,2*nbin+1,by=2)]
-  aves      <- indexQnt[seq(2,2*nbin,  by=2)]  
+  binctr    <- indexQnt[seq(2,2*nbin,  by=2)]  
   freq      <- matrix(0,nbin,1)
   freq[1]   <- sum(percntrnk < bdry[2])
   for (k in 2:nbin) {
@@ -327,28 +327,32 @@ Sbinsmth.init <- function(percntrnk, nbin, SfdPar, grbgvec, noption, chcemat) {
   }
   meanfreq <- mean(freq)
   SfdList  <- vector("list", nitem)
-  Sfd      <- SfdPar$fd
-  Sbasis   <- Sfd$basis
   Snbasis  <- Sbasis$nbasis
+  index    <- percntrnk
   
   #. --------------------------------------------------------------------------
   #. loop through items to compute their surprisal curve approximations
   #. --------------------------------------------------------------------------
   
-  for (item in 1:nitem) {
+  for (item in 1:n) {
     Mi    <- noption[item]
     logMi <- log(Mi)
-    chcematveci <- as.numeric(chcemat[,item])
+    chceveci <- as.numeric(chcemat[,item])
+    Zmati <- fda::zerobasis(Mi)
     Pbin  <- matrix(0,nbin,Mi)  #  probabilities
     Sbin  <- matrix(0,nbin,Mi)  #  transformation of probability
     for (k in 1:nbin) {
       #  index of percntrnk values within this bin
-      indk   <- percntrnk >= bdry[k] & percntrnk <= bdry[k+1]
+      if (k == 1) {
+        indk <- percntrnk <= bdry[2]
+      } else {
+        indk <- percntrnk > bdry[k] & percntrnk <= bdry[k+1]
+      }
       if (sum(indk) > 0) {
-        chcematvecik <- chcematveci[indk]
         nk     <- sum(indk)
         for (m in 1:Mi) {
-          Pbin[k,m] <- sum(chcematvecik == m)/nk
+          #  item choice probabilities
+          Pbin[k,m] <- sum(chceveci[indk] == m)/nk
           if (Pbin[k,m] == 0) Pbin[k,m] <- NA
         }
         Sbin[k,] <- -log(Pbin[k,])/logMi
@@ -385,8 +389,8 @@ Sbinsmth.init <- function(percntrnk, nbin, SfdPar, grbgvec, noption, chcemat) {
         nonindm <- (1:nbin)[Smis.na]
         if (indmlen > 3) {
           SY <- Sbin[indm,m];
-          SX <- cbind(rep(1,indmlen), aves[indm])
-          BX <- lsfit(aves[indm], SY)$coefficients
+          SX <- cbind(rep(1,indmlen), binctr[indm])
+          BX <- lsfit(binctr[indm], SY)$coefficients
           Sbin[indm,m]    <- SX %*% BX
           Sbin[nonindm,m] <- SurprisalMax
         } else {
@@ -395,43 +399,165 @@ Sbinsmth.init <- function(percntrnk, nbin, SfdPar, grbgvec, noption, chcemat) {
       }
     }
     
-    #  generate a map into M-vectors with zero row sums
-    
-    if (Mi == 2) {
-      root2 <- sqrt(2)
-      Zmati <- matrix(1/c(root2,-root2),2,1)
-    } else {
-      Zmati <- fda::zerobasis(Mi)
-    }
-    
     #  apply conventional smoothing of surprisal values
-    Sfdi     <- fda::smooth.basis(aves, Sbin, SfdPar)$fd
+    #  here the bin values are smoothed and the number of
+    #  coefficients Sfdiniti will be M.
+    Sfdiniti     <- fda::smooth.basis(binctr, Sbin, Sbasis)$fd
     #  compute spline basis functions at bin centres
-    Phimati  <- fda::eval.basis(aves, SfdPar$fd$basis)
+    Phimati  <- fda::eval.basis(binctr, Sbasis)
     #  evaluate smooth at bin centres
-    Smathati <- fda::eval.fd(aves, Sfdi)
+    Smathati <- fda::eval.fd(binctr, Sfdiniti)
     #  map this into zero-row-sum space
     Smatctri <- Smathati %*% Zmati
     #  regress the centred data on the negative of basis values
     Result <- lsfit(-Phimati, Smatctri, intercept=FALSE)
+    #  the coefficients of the regression are the initial values
+    #  for subsequent surprisal smoothing in function Sbinsmth
     Bmati  <- Result$coefficient
-    Sfdi   <- fda::fd(Bmati, Sbasis)
+    #  Define Sfdi, the functional data object that will be the initial 
+    #  estimate of the Mi - 1 surprisal curves for item i.
+    #  Here Sfdi is defined with Mi - 1 coefficients
+    Sfdi <- fda::fd(Bmati, Sbasis)
     
     #  store objects in SListi
     
     SListi <- list(
       Sfd        = Sfdi,       #  functional data object for (options
       M          = Mi,         #  the number of options
-      Pbin       = Pbin,       # proportions at each bin
-      Sbin       = Sbin,       # negative surprisals at each bin
+      Zmat       = Zmati,      #  M by M-1 matrix to transform B into X
+      Pbin       = Pbin,       #  proportions at each bin
+      Sbin       = Sbin,       #  negative surprisals at each bin
       Pmatfine   = NULL,   
       Smatfine   = NULL,   
       DSmatfine  = NULL,  
       D2Smatfine = NULL  
     )
-    SfdList[[item]] <- SListi
+    SfdList[[item]] = SListi
   }
-
+  
+  # print("after n")
+  # print(length(SfdList))
+  
+  #. --------------------------------------------------------------------------
+  #. Compute SListi for the extra guessing item
+  #. --------------------------------------------------------------------------
+  
+  if (length(SfdList) == n + 1) {
+    Mi    <- 3
+    logMi <- log(3)
+    Zmati <- fda::zerobasis(3)
+    
+    #  compute frequencies for each bin
+    
+    freq <- matrix(0,nbin,1)
+    freq[1] <- sum(index < bdry[2])
+    for (k in 2:nbin) {
+      freq[k] <- sum(bdry[k-1] < index & index <= bdry[k])
+    }
+    
+    #. probability and surprisal of choosing 1 or 3 given wrong answer
+    
+    Pbin  <- matrix(0,nbin,Mi)  #  probabilities
+    Sbin  <- matrix(0,nbin,Mi)  #  transformation of probability
+    
+    for (k in 1:nbin) {
+      if (k == 1) {
+        indk <- percntrnk <= bdry[2] 
+      } else {
+        indk <- percntrnk > bdry[k] & percntrnk <= bdry[k+1]
+      }
+      for (item in 1:n) {
+        keyi <- key[item]
+        chceveci <- as.numeric(chcemat[,item])
+        indi1 <- chceveci != keyi & chceveci == 1
+        Pbin[k,1] <- Pbin[k,1] + sum(indk & indi1)
+        indi3 <- chceveci != keyi & chceveci == 3
+        Pbin[k,2] <- Pbin[k,2] + sum(indk & indi3)
+        indix <- chceveci != keyi & chceveci != 1 & chceveci != 3
+        Pbin[k,3] <- Pbin[k,3] + sum(indk & indix)
+      }
+      Pbinsumk <- sum(Pbin[k,])
+      Pbin[k,] <- Pbin[k,]/Pbinsumk
+      Sbin[k,] <- -log(Pbin[k,])/logMi
+    }
+    
+    # print(round(Pbin,2))
+    # matplot(1:20, Pbin, type="b")
+    # 
+    # print(round(Sbin,2))
+    # matplot(1:20, Sbin, type="b")
+    
+    Mi    <- 3
+    logMi <- 1.098612
+    Zmati <- t(matrix(c( 0.7071068,  0.4082483, 0.0, 
+                         -0.8164966, -0.7071068, 0.4082483),2,3))
+    
+    #. probability and surprisal of choosing 1 or 3 given any. answer
+    
+    Pbin  <- matrix(0,nbin,Mi)  #  probabilities
+    Sbin  <- matrix(0,nbin,Mi)  #  transformation of probability
+    
+    for (k in 1:nbin) {
+      if (k == 1) {
+        indk <- percntrnk <= bdry[2] 
+      } else {
+        indk <- percntrnk > bdry[k] & percntrnk <= bdry[k+1]
+      }
+      for (item in 1:n) {
+        keyi <- key[item]
+        chceveci <- as.numeric(chcemat[,item])
+        indi1 <- chceveci == 1
+        Pbin[k,1] <- Pbin[k,1] + sum(indk & indi1)
+        indi3 <- chceveci == 3
+        Pbin[k,2] <- Pbin[k,2] + sum(indk & indi3)
+        indix <- chceveci != 1 & chceveci != 3
+        Pbin[k,3] <- Pbin[k,3] + sum(indk & indix)
+      }
+      Pbinsumk <- sum(Pbin[k,])
+      Pbin[k,] <- Pbin[k,]/Pbinsumk
+      Sbin[k,] <- -log(Pbin[k,])/logMi
+    }
+  }
+  
+  #  apply conventional smoothing of surprisal values
+  #  here the bin values are smoothed and the number of
+  #  coefficients Sfdiniti will be M.
+  Sfdiniti     <- fda::smooth.basis(binctr, Sbin, Sbasis)$fd
+  #  compute spline basis functions at bin centres
+  Phimati  <- fda::eval.basis(binctr, Sbasis)
+  #  evaluate smooth at bin centres
+  Smathati <- fda::eval.fd(binctr, Sfdiniti)
+  #  map this into zero-row-sum space
+  Smatctri <- Smathati %*% Zmati
+  #  regress the centred data on the negative of basis values
+  Result <- lsfit(-Phimati, Smatctri, intercept=FALSE)
+  #  the coefficients of the regression are the initial values
+  #  for subsequent surprisal smoothing in function Sbinsmth
+  Bmati  <- Result$coefficient
+  #  Define Sfdi, the functional data object that will be the initial 
+  #  estimate of the Mi - 1 surprisal curves for item i.
+  #  Here Sfdi is defined with Mi - 1 coefficients
+  Sfdi <- fda::fd(Bmati, Sbasis)
+  
+  # print(round(Bmati,2))
+  # 
+  # plot(Sfdi)
+  
+  SListi <- list(
+    Sfd        = Sfdi,       #  functional data object for (options
+    M          = Mi,         #  the number of options
+    Zmat       = Zmati,      #  M by M-1 matrix to transform B into X
+    Pbin       = Pbin,       #  proportions at each bin
+    Sbin       = Sbin,       #  negative surprisals at each bin
+    Pmatfine   = NULL,   
+    Smatfine   = NULL,   
+    DSmatfine  = NULL,  
+    D2Smatfine = NULL  
+  )
+  SfdList[[nitem]] = SListi
+  
+  print(paste("length SfdList =", length(SfdList)))
+  
   return(SfdList)
   
 }
